@@ -1,5 +1,5 @@
 define(function (require) {
-  var visTypes = require('ui/registry/vis_types');
+  const visTypes = require('ui/registry/vis_types');
   visTypes.register(require('plugins/kbn_vislib_vis_types/histogram'));
   visTypes.register(require('plugins/kbn_vislib_vis_types/line'));
   visTypes.register(require('plugins/kbn_vislib_vis_types/pie'));
