@@ -25,7 +25,8 @@ module.exports = function (kibana) {
           var config = server.config();
 
           return {
-            kbnDefaultAppId: config.get('kibana.defaultAppId')
+            kbnDefaultAppId: config.get('kibana.defaultAppId'),
+            tilemap: config.get('tilemap')
           };
         }
       }
