@@ -1,7 +1,7 @@
 define(function (require) {
   return function visualizationLoader(savedVisualizations, Private) { // Inject services here
-    var brushEvent = Private(require('ui/utils/brush_event'));
-    var filterBarClickHandler = Private(require('ui/filter_bar/filter_bar_click_handler'));
+    const brushEvent = Private(require('ui/utils/brush_event'));
+    const filterBarClickHandler = Private(require('ui/filter_bar/filter_bar_click_handler'));
 
     return function (panel, $scope) { // Function parameters here
       return savedVisualizations.get(panel.id)
