@@ -1,9 +1,9 @@
 require('ui/modules')
 .get('apps/discover')
 .directive('discoverTimechart', function (Private, $compile) {
-  var _ = require('lodash');
-  var $ = require('jquery');
-  var vislib = Private(require('ui/vislib'));
+  const _ = require('lodash');
+  const $ = require('jquery');
+  const vislib = Private(require('ui/vislib'));
 
   return {
     restrict: 'E',
@@ -12,9 +12,9 @@ require('ui/modules')
     },
     link: function ($scope, elem) {
 
-      var init = function () {
+      const init = function () {
         // This elem should already have a height/width
-        var myChart = new vislib.Chart(elem[0], {
+        const myChart = new vislib.Chart(elem[0], {
 
         });
 
