@@ -2,9 +2,9 @@ define(function (require) {
   require('ui/modules')
   .get('kibana')
   .directive('nestingIndicator', function ($rootScope, $parse, Private) {
-    var _ = require('lodash');
-    var $ = require('jquery');
-    var getColors = Private(require('ui/vislib/components/color/color_palette'));
+    const _ = require('lodash');
+    const $ = require('jquery');
+    const getColors = Private(require('ui/vislib/components/color/color_palette'));
 
     return {
       restrict: 'E',
@@ -16,10 +16,10 @@ define(function (require) {
         $scope.$watchCollection('list', function () {
           if (!$scope.list || !$scope.item) return;
 
-          var item = $scope.item;
-          var index = $scope.list.indexOf($scope.item);
-          var bars = $scope.list.slice(0, index + 1);
-          var colors = getColors(bars.length);
+          const item = $scope.item;
+          const index = $scope.list.indexOf($scope.item);
+          const bars = $scope.list.slice(0, index + 1);
+          const colors = getColors(bars.length);
 
           $el.html(bars.map(function (bar, i) {
             return $(document.createElement('span'))
