@@ -2,7 +2,7 @@ define(function (require) {
   require('ui/modules')
   .get('app/visualize')
   .directive('visEditorSidebar', function () {
-    var _ = require('lodash');
+    const _ = require('lodash');
 
     require('plugins/kibana/visualize/editor/agg_group');
     require('plugins/kibana/visualize/editor/vis_options');
@@ -15,7 +15,12 @@ define(function (require) {
       controller: function ($scope) {
         $scope.$bind('vis', 'editableVis');
         $scope.$bind('outputVis', 'vis');
-        this.section = _.get($scope, 'vis.type.requiresSearch') ? 'data' : 'options';
+        $scope.$watch('vis.type', (visType) => {
+          if (visType) {
+            this.showData = visType.schemas.buckets || visType.schemas.metrics;
+            this.section = this.section || (this.showData ? 'data' : 'options');
+          }
+        });
       }
     };
   });
