@@ -1,4 +1,4 @@
-var _ = require('lodash');
+const _ = require('lodash');
 
 // Turns thisIsASentence to
 // This Is A Sentence
