@@ -1,7 +1,7 @@
 'use strict';
 
 module.exports = function (kbnServer) {
-  var Config = require('./Config');
+  var Config = require('./config');
   var schema = require('./schema')();
 
   kbnServer.config = new Config(schema, kbnServer.settings || {});
