@@ -1,5 +1,7 @@
 'use strict';
 
+var _regeneratorRuntime = require('babel-runtime/regenerator')['default'];
+
 module.exports = function (kbnServer, server, config) {
   var _ = require('lodash');
   var fs = require('fs');
@@ -12,6 +14,8 @@ module.exports = function (kbnServer, server, config) {
 
   server = kbnServer.server = new Hapi.Server();
 
+  var shortUrlLookup = require('./short_url_lookup')(server);
+
   // Create a new connection
   var connectionOptions = {
     host: config.get('server.host'),
@@ -20,7 +24,10 @@ module.exports = function (kbnServer, server, config) {
       strictHeader: false
     },
     routes: {
-      cors: config.get('server.cors')
+      cors: config.get('server.cors'),
+      payload: {
+        maxBytes: config.get('server.maxPayloadBytes')
+      }
     }
   };
 
@@ -133,5 +140,53 @@ module.exports = function (kbnServer, server, config) {
     }
   });
 
+  server.route({
+    method: 'GET',
+    path: '/goto/{urlId}',
+    handler: function handler(request, reply) {
+      var url;
+      return _regeneratorRuntime.async(function handler$(context$2$0) {
+        while (1) switch (context$2$0.prev = context$2$0.next) {
+          case 0:
+            context$2$0.next = 2;
+            return _regeneratorRuntime.awrap(shortUrlLookup.getUrl(request.params.urlId));
+
+          case 2:
+            url = context$2$0.sent;
+
+            reply().redirect(config.get('server.basePath') + url);
+
+          case 4:
+          case 'end':
+            return context$2$0.stop();
+        }
+      }, null, this);
+    }
+  });
+
+  server.route({
+    method: 'POST',
+    path: '/shorten',
+    handler: function handler(request, reply) {
+      var urlId;
+      return _regeneratorRuntime.async(function handler$(context$2$0) {
+        while (1) switch (context$2$0.prev = context$2$0.next) {
+          case 0:
+            context$2$0.next = 2;
+            return _regeneratorRuntime.awrap(shortUrlLookup.generateUrlId(request.payload.url));
+
+          case 2:
+            urlId = context$2$0.sent;
+
+            reply(urlId);
+
+          case 4:
+          case 'end':
+            return context$2$0.stop();
+        }
+      }, null, this);
+    }
+  });
+
   return kbnServer.mixin(require('./xsrf'));
 };
