@@ -4,7 +4,7 @@ define(function (require) {
   var rison = require('ui/utils/rison');
   var keymap = require('ui/utils/key_map');
 
-  module.directive('savedObjectFinder', function ($location, $injector, kbnUrl, Private) {
+  module.directive('savedObjectFinder', function ($location, $injector, kbnUrl, Private, config) {
 
     var services = Private(require('ui/saved_objects/saved_object_registry')).byLoaderPropertiesName;
 
@@ -23,6 +23,9 @@ define(function (require) {
       controller: function ($scope, $element, $timeout) {
         var self = this;
 
+        // The number of items to show in the list
+        $scope.perPage = config.get('savedObjects:perPage');
+
         // the text input element
         var $input = $element.find('input[ng-model=filter]');
 
