@@ -5,6 +5,5 @@ require('node_modules/angular/angular');
 module.exports = window.angular;
 
 require('node_modules/angular-elastic/elastic');
-require('node_modules/angular-route/angular-route');
 
-require('ui/modules').get('kibana', ['ngRoute', 'monospaced.elastic']);
+require('ui/modules').get('kibana', ['monospaced.elastic']);
